pub enum Direction {
Forward,
Backward,
}Expand description
Which way find scans from its from position. Re-exported at the
crate root as SearchDir.
Variants
Forward
Towards the end of the buffer (/, n after /): the first match
starting at or after from, wrapping to the start.
Backward
Towards the start of the buffer (?, n after ?): the last match
starting at or before from, wrapping to the end.