glyph_for_entry

Function glyph_for_entry 

pub fn glyph_for_entry(
    path: &Path,
    is_dir: bool,
    nerd_fonts: bool,
) -> &'static str
Glyph-only resolver. Used by the file-tree / oil rope renderers that embed the glyph in editable text and let the renderer apply styling spans. Equivalent to the first half of entry_visual.